@@ -1,6 +1,7 @@
 import copy
 from collections import KeysView, ValuesView
 from typing import Optional
+import os
 
 
 class Properties:
@@ -21,11 +22,17 @@ class Properties:
         self.separator_char = kwargs.get('separator_char', '=')
         self.comment_char = kwargs.get('comment_char', '#')
         if path:
-            self.load(path, self.comment_char, self.separator_char)
+            self.load(path, self.separator_char, self.comment_char)
 
     def __repr__(self):
         return f"<{self.__class__}, loaded_file: '{self.path if self.path else 'None'}'>"
 
+    def getPath(self) -> str:
+        """Used to get the path of the file stored
+        :return: str, the path of the file stored
+        """
+        return self.path
+
     def load(self, path: str, separator_char: str = '=', comment_char: str = '#') -> 'Properties':
         """ Loads Properties and stores them in a dict and returns the dict
         :param path: string path as relative {used with a context manager}
@@ -34,16 +41,12 @@ class Properties:
         :return: Dict of content
         """
         self.content = {}
-        self.path = path
         self.prev_key = ''
-        self.separator_char = separator_char
-        self.comment_char = comment_char
         try:
             with open(path, 'r') as f:
                 strContent = f.readlines()
                 for line in strContent:
                     line = line.replace('\n', '').strip()
-
                     if self.prev_key != '':
                         self.content[self.prev_key] += ' ' + line
 
@@ -58,7 +61,10 @@ class Properties:
                         self.prev_key = ''
 
                 f.close()
-                self.prev_key = ''
+            self.prev_key = ''
+            self.path = path
+            self.separator_char = separator_char
+            self.comment_char = comment_char
         except FileNotFoundError as e:
             print(e)
         return self
@@ -67,7 +73,7 @@ class Properties:
         """Reloads the property file"""
         if not self.path:
             raise Exception('No path given, cannot reload properties')
-        self.load(self.path, self.comment_char, self.separator_char)
+        self.load(self.path, self.separator_char, self.comment_char)
 
     def getProperty(self, key: str) -> str:
         """Returns the key
@@ -139,7 +145,7 @@ class Properties:
         """
         return self.content.__contains__(key)
 
-    def out(self, path: str, separator_char: str = '=', comment_char: str = '#' , comments=None,
+    def out(self, path: str = None, separator_char: str = '=', comment_char: str = '#', comments=None,
             comments_pos: str = 'top'):
         """Used to write a properties file
         :param path: string path as relative {used with a context manager}
@@ -149,6 +155,11 @@ class Properties:
         :type comments: list[str]
         :param comments_pos: position of the comments, must be 'top' or 'bottom'
         """
+        if path is None:
+            if self.path != '':
+                path = self.path
+            else:
+                return False
         if comments is None:
             comments = []
         if not hasattr(comments, '__iter__'):
@@ -167,8 +178,9 @@ class Properties:
 
 
 class PropertiesHandler:
-    properties_dict: dict
+    properties_dict: dict[str, Properties]
     curr_prop: Optional[Properties]
+    directories_dict: dict
 
     def __init__(self, properties_list=None):
         """Creates a 'PropertiesHandler' object used to manage and switch easily between Properties objects,
@@ -178,6 +190,7 @@ class PropertiesHandler:
         if properties_list is None:
             properties_list = []
         self.properties_dict = {}
+        self.directories_dict = {}
         self.curr_prop = None
         if properties_list:
             for prop in properties_list:
@@ -224,6 +237,78 @@ class PropertiesHandler:
                     continue
         return self
 
+    def setDirectory(self, absolute_path: str):
+        """Used to set a single directory as the container for all .properties files,
+         removes every other Properties objects stored
+        :param absolute_path: absolute path to directory
+        """
+        if not absolute_path.endswith('\\'):
+            absolute_path += '\\'
+        self.directories_dict[absolute_path] = []
+        self.properties_dict = {}
+        self.curr_prop = None
+        for file in os.listdir(absolute_path):
+            if file.endswith(".properties"):
+                self.directories_dict[absolute_path].append(absolute_path + file)
+                self.addProperty(Properties(os.path.join(absolute_path + file)))
+
+    def addDirectory(self, absolute_path: str):
+        """Used to add a directory to the Properties directories list
+        :param absolute_path: absolute path to directory
+        """
+        if not absolute_path.endswith('\\'):
+            absolute_path += '\\'
+        self.directories_dict[absolute_path] = []
+        for file in os.listdir(absolute_path):
+            if file.endswith(".properties"):
+                self.directories_dict[absolute_path].append(absolute_path + file)
+                self.addProperty(Properties(os.path.join(absolute_path + file)))
+
+    def removeDirectories(self):
+        """Removes every directory added to the Directories list
+        Keeps externally added files"""
+        for absolute_path in copy.deepcopy(list(self.directories_dict.keys())):
+            self.removeDirectory(absolute_path)
+
+    def removeDirectory(self, absolute_path: str):
+        """Removes a directory and it's properties objects from the directories list
+        :param absolute_path: absolute path to the directory
+        """
+        if not absolute_path.endswith('\\'):
+            absolute_path += '\\'
+        if not absolute_path in self.directories_dict.keys():
+            raise AttributeError(f"Directory '{absolute_path}' isn't registered.")
+        for prop_path in self.directories_dict[absolute_path]:
+            prop = self._getPropertyByPath(prop_path)
+            self.properties_dict.pop(list(self.properties_dict.keys())
+                                     [list(self.properties_dict.values()).index(prop)])
+        self.directories_dict.pop(absolute_path)
+
+    def updateDirectories(self):
+        """Reloads every Properties objects contained in a stored directory
+        and adds new files that were created after previous loading"""
+        for relative_path in self.directories_dict.keys():
+            for file in os.listdir(relative_path):
+                if file.endswith(".properties"):
+                    fileName = relative_path + file
+                    if fileName not in self.directories_dict[relative_path]:
+                        self.addProperty(Properties(os.path.join(relative_path + file)))
+                    else:
+                        self._getPropertyByPath(fileName).reload()
+
+    def updateAll(self):
+        """Reloads every Properties objects"""
+        for prop in self.properties_dict.values():
+            prop.reload()
+
+    def _getPropertyByPath(self, path: str) -> Properties:
+        """Used to get a Property object using it's absolute path
+        :param path: str, absolute path to the property
+        """
+        for prop in self.properties_dict.values():
+            if prop.getPath() == path:
+                return prop
+
     def addProperty(self, prop: Properties, name: str = ''):
         """Adds a Properties object
         :param prop: Properties object
@@ -247,7 +332,7 @@ class PropertiesHandler:
         name = kwargs.get('name', False)
         index = kwargs.get('index', False)
         prop: Optional[Properties] = None
-        if name:
+        if isinstance(name, str):
             if not self.properties_dict.__contains__(name):
                 raise KeyError(f'Unknown key {name}')
             prop = self.properties_dict.get(name)
@@ -260,8 +345,7 @@ class PropertiesHandler:
         if prop == self.curr_prop:
             curr_index = list(self.properties_dict.values()).index(prop)
             self.curr_prop = self.properties_dict.get(list(self.properties_dict.keys())
-                                                      [(
-                    curr_index - 1 if curr_index == len(self.properties_dict) else curr_index)])
+                                                      [(curr_index - 1 if curr_index == len(self.properties_dict) else curr_index)])
         return self.properties_dict.pop(list(self.properties_dict.keys())
                                         [list(self.properties_dict.values()).index(prop)])
 
